@@ -3,7 +3,7 @@ import numpy.random
 from dataclasses import dataclass
 from typing import Sequence, Tuple
 import scipy.optimize
-from pdme.model.model import Model
+from pdme.model.model import Model, Discretisation
 from pdme.measurement import DotMeasurement, OscillatingDipoleArrangement, OscillatingDipole
 
 
@@ -32,6 +32,7 @@ class FixedDipoleModel(Model):
 	def __repr__(self) -> str:
 		return f'FixedDipoleModel({self.xmin}, {self.xmax}, {self.ymin}, {self.ymax}, {self.zmin}, {self.zmax}, {self.p}, {self.n()})'
 
+	# TODO: this signature doesn't make sense.
 	def get_dipoles(self, frequency: float) -> OscillatingDipoleArrangement:
 		s_pts = numpy.array((self.rng.uniform(self.xmin, self.xmax), self.rng.uniform(self.ymin, self.ymax), self.rng.uniform(self.zmin, self.zmax)))
 		return OscillatingDipoleArrangement([OscillatingDipole(self.p, s_pts, frequency)])
@@ -74,7 +75,7 @@ class FixedDipoleModel(Model):
 
 
 @dataclass
-class FixedDipoleDiscretisation():
+class FixedDipoleDiscretisation(Discretisation):
 	'''
 	Representation of a discretisation of a FixedDipoleDiscretisation.
 	Also captures a rough maximum value of dipole.
@@ -101,7 +102,7 @@ class FixedDipoleDiscretisation():
 		self.y_step = (self.model.ymax - self.model.ymin) / self.num_y
 		self.z_step = (self.model.zmax - self.model.zmin) / self.num_z
 
-	def bounds(self, index: Tuple[float, float, float]) -> Tuple:
+	def bounds(self, index: Tuple[float, ...]) -> Tuple:
 		xi, yi, zi = index
 
 		# For this model, a point is (sx, sx, sy, w).
@@ -121,7 +122,7 @@ class FixedDipoleDiscretisation():
 		# see https://github.com/numpy/numpy/issues/20706 for why this is a mypy problem.
 		return numpy.ndindex((self.num_x, self.num_y, self.num_z))  # type:ignore
 
-	def solve_for_index(self, dots: Sequence[DotMeasurement], index: Tuple[float, float, float]) -> scipy.optimize.OptimizeResult:
+	def solve_for_index(self, dots: Sequence[DotMeasurement], index: Tuple[float, ...]) -> scipy.optimize.OptimizeResult:
 		bounds = self.bounds(index)
 		sx_mean = (bounds[0][0] + bounds[1][0]) / 2
 		sy_mean = (bounds[0][1] + bounds[1][1]) / 2
