@@ -2,8 +2,8 @@ import numpy
 from dataclasses import dataclass
 from typing import Sequence, Tuple
 import scipy.optimize
-from pdme.model.model import Model
-from pdme.measurement import DotMeasurement
+from pdme.model.model import Model, Discretisation
+from pdme.measurement import DotMeasurement, OscillatingDipoleArrangement, OscillatingDipole
 
 
 class UnrestrictedModel(Model):
@@ -25,6 +25,7 @@ class UnrestrictedModel(Model):
 		self.zmax = zmax
 		self.max_p = max_p
 		self._n = n
+		self.rng = numpy.random.default_rng()
 
 	def __repr__(self) -> str:
 		return f'UnrestrictedModel({self.xmin}, {self.xmax}, {self.ymin}, {self.ymax}, {self.zmin}, {self.zmax}, {self.max_p}, {self.n()})'
@@ -69,9 +70,19 @@ class UnrestrictedModel(Model):
 
 		return numpy.concatenate((p_divs, r_divs, w_div), axis=None)
 
+	def get_dipoles(self, frequency: float) -> OscillatingDipoleArrangement:
+		theta = numpy.arccos(self.rng.uniform(-1, 1))
+		phi = self.rng.uniform(0, 2 * numpy.pi)
+		p = self.rng.uniform(0, self.max_p)
+		px = p * numpy.sin(theta) * numpy.cos(phi)
+		py = p * numpy.sin(theta) * numpy.sin(phi)
+		pz = p * numpy.cos(theta)
+		s_pts = numpy.array((self.rng.uniform(self.xmin, self.xmax), self.rng.uniform(self.ymin, self.ymax), self.rng.uniform(self.zmin, self.zmax)))
+		return OscillatingDipoleArrangement([OscillatingDipole(numpy.array([px, py, pz]), s_pts, frequency)])
+
 
 @dataclass
-class UnrestrictedDiscretisation():
+class UnrestrictedDiscretisation(Discretisation):
 	'''
 	Representation of a discretisation of a UnrestrictedModel.
 	Also captures a rough maximum value of dipole.
@@ -113,7 +124,7 @@ class UnrestrictedDiscretisation():
 		self.py_step = 2 * self.max_p / self.num_py
 		self.pz_step = 2 * self.max_p / self.num_pz
 
-	def bounds(self, index: Tuple[float, float, float, float, float, float]) -> Tuple:
+	def bounds(self, index: Tuple[float, ...]) -> Tuple:
 		pxi, pyi, pzi, xi, yi, zi = index
 
 		# For this model, a point is (px, py, pz, sx, sx, sy, w).
@@ -135,7 +146,7 @@ class UnrestrictedDiscretisation():
 		# see https://github.com/numpy/numpy/issues/20706 for why this is a mypy problem.
 		return numpy.ndindex((self.num_px, self.num_py, self.num_pz, self.num_x, self.num_y, self.num_z))  # type:ignore
 
-	def solve_for_index(self, dots: Sequence[DotMeasurement], index: Tuple[float, float, float, float, float, float]) -> scipy.optimize.OptimizeResult:
+	def solve_for_index(self, dots: Sequence[DotMeasurement], index: Tuple[float, ...]) -> scipy.optimize.OptimizeResult:
 		bounds = self.bounds(index)
 		px_mean = (bounds[0][0] + bounds[1][0]) / 2
 		py_mean = (bounds[0][1] + bounds[1][1]) / 2
